[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - lzw.BitPacker: Translates a stream of lzw codepoints into a variable width packed stream of bytes, for use by BitUnpacker.
  - lzw.BitUnpacker: An adaptive-width bit unpacker, intended to decode streams written by BitPacker into integer codepoints.
  - lzw.ByteDecoder: Decodes, combines bit-unpacking and interpreting a codepoint stream, suitable for use with bytes generated by ByteEncoder.
  - lzw.ByteEncoder: Takes a stream of uncompressed bytes and produces a stream of compressed bytes, usable by ByteDecoder.
  - lzw.Decoder: Uncompresses a stream of lzw code points, as created by Encoder.
  - lzw.Encoder: Given an iterator of bytes, returns an iterator of integer codepoints, suitable for use by Decoder.
  - lzw.PagingDecoder: UNTESTED.
  - lzw.PagingEncoder: UNTESTED.